#include "menu.h"
#include "config.h"
#include "gfxinterface.h"
#include "input.h"
#include "time_util.h"


const char * menu_lines[] = {
	"XGalaga++",
	"v0.2 (2003-09-30)",
	"",
	"2003 Marc Mongenet, pictures from XGalaga 2.0.34",
	"This game is free software, covered by the GPL.",
	"",
	"Key             Action",
	"             ",
	"s               start",
	"q               quit",
	"p               pause",
	"+               increase details (slower)",
	"-               decrease details (faster)",
	"<space bar>     fire",
	"<left arrow>    move left",
	"<right arrow>   move right",
};


StartMenu * StartMenu::singleton_ (0);


StartMenu::StartMenu()
: font_(X11::Inst().LoadQueryFont("*-fixed-bold-r-*"))
, width_(0)
{
	if (!font_) throw std::runtime_error ("X font error");

	for (size_t i (0); i < sizeof menu_lines / sizeof menu_lines[0]; ++i) {
		width_ = std::max(width_, XTextWidth(font_, menu_lines[i],
		                                     std::strlen(menu_lines[i])));
	}
}


StartMenu::~StartMenu()
{
	X11::Inst().FreeFont(font_);
}


bool StartMenu::Display(std::vector<StarsField> * stars_fields, Score * score) const
{
	Input input;
        for (;;) {
		const double start_frame_time (CurrentMicroSecond());
		input.Update();
		if (input.Quit()) return false;
		if (input.Start()) return true;
		Details::Instance().Change(input.Details());
		X11::Inst().GetWindowAttributes();
		ScrollStarFields(stars_fields);
		score->Refresh();
		Print();
		X11::Inst().Sync(False);
		WaitNextFrame(start_frame_time);
	}
}


void StartMenu::Print() const
{
	const int left (std::max(0, (X11::Inst().WindowWidth() - width_) / 2));
	Coord pos (left ,20);
	X11::Inst().SetForeground(X11::Inst().GetWhite());
	X11::Inst().SetFont(font_->fid);
	for (size_t i (0); i < sizeof menu_lines / sizeof menu_lines[0]; ++i) {
		X11::Inst().DrawString(pos, menu_lines[i]);
		pos.AddY(font_->ascent + font_->descent + 1);
	}
}
